function [data, auxData, metaData, txtData, weights] = mydata_Burhinus_oedicnemus

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Charadriiformes'; 
metaData.family     = 'Burhinidae';
metaData.species    = 'Burhinus_oedicnemus'; 
metaData.species_en = 'Eurasian stone-curlew'; 

metaData.ecoCode.climate = {'BSk','BWk','Csa','Cfb','Dfa'};
metaData.ecoCode.ecozone = {'THp'};
metaData.ecoCode.habitat = {'0iTi', '0iTg'};
metaData.ecoCode.embryo  = {'Tnsfm'};
metaData.ecoCode.migrate = {'Ms'};
metaData.ecoCode.food    = {'biC'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};

metaData.T_typical  = C2K(41); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2022 11 02];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@akvaplan.niva.no'}; 
metaData.date_acc    = [2022 11 02]; 

%% set data
% zero-variate data

data.ab = 25;      units.ab = 'd';    label.ab = 'age at birth';           bibkey.ab = 'Wiki';   
  temp.ab = C2K(37); units.temp.ab = 'K'; label.temp.ab = 'temperature';
  comment.ab = '24 to 26 d';
data.tx = 39;      units.tx = 'd';     label.tx = 'time since birth at fledging'; bibkey.tx = 'Wiki';   
  temp.tx = C2K(41); units.temp.tx = 'K'; label.temp.tx = 'temperature';
  comment.tx = '36-42 d';
data.tR = 2*365;     units.tR = 'd';    label.tR = 'time since birth at 1st brood'; bibkey.tR = 'AnAge';
  temp.tR = C2K(41); units.temp.tR = 'K'; label.temp.tR = 'temperature';
data.am = 17.9*365;  units.am = 'd';   label.am = 'life span';             bibkey.am = 'AnAge';   
  temp.am = C2K(41); units.temp.am = 'K'; label.temp.am = 'temperature';

data.Wwb = 38.3;    units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'West1983';
data.Wwi = 535.2;   units.Wwi = 'g';   label.Wwi = 'ultimate wet weight for female'; bibkey.Wwi = 'Wiki';
  comment.Wwi = '290-535 g';
  
data.Ri  = 2/365; units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';    bibkey.Ri  = 'Wiki';   
  temp.Ri = C2K(41); units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  comment.Ri = '2 eggs per clutch; 1 clutch per yr';
  
% uni-variate data
% time-weight 
data.tW = [ ... % time since birth (d), wet weight (g)
0.148	38.332
0.149	35.219
0.923	33.321
1.078	30.606
1.386	33.738
1.387	31.403
1.925	39.996
1.926	36.884
3.860	32.332
4.016	28.450
5.706	55.790
5.941	49.579
6.856	80.374
6.858	75.316
7.095	62.879
7.177	51.600
7.862	76.933
7.863	75.377
11.175	104.761
12.799	102.914
12.869	121.985
13.802	107.644
13.952	120.105
14.042	87.036
16.081	210.118
19.013	223.526
19.056	113.800
23.105	235.837
24.874	259.679
26.034	258.583
26.050	215.393
28.966	343.000
31.368	363.000];
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(41);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW  = 'West1983';

%% set weights for all real data
weights = setweights(data, []);
weights.tW = 2 * weights.tW;
weights.Wwb = 5 * weights.Wwb;
weights.Wwi = 5 * weights.Wwi;
weights.tx = 2 * weights.tx;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Discussion points
D1 = 'body temp guesses';
metaData.discussion = struct('D1',D1);

%% Links
metaData.links.id_CoL = 'NXG9'; % Cat of Life
metaData.links.id_ITIS = '176749'; % ITIS
metaData.links.id_EoL = '45513584'; % Ency of Life
metaData.links.id_Wiki = 'Burhinus_oedicnemus'; % Wikipedia
metaData.links.id_ADW = 'Burhinus_oedicnemus'; % ADW
metaData.links.id_Taxo = '53524'; % Taxonomicon
metaData.links.id_WoRMS = '416696'; % WoRMS
metaData.links.id_avibase = 'C7DB323E37CEDBE6'; % avibase
metaData.links.id_birdlife = 'eurasian-thick-knee-burhinus-oedicnemus'; % birdlife
metaData.links.id_AnAge = 'Burhinus_oedicnemus'; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Burhinus_oedicnemus}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'West1983'; type = 'article'; bib = [ ...  
'title = {Breeding of Stone-curlews at {W]eeting {H}eath, {N}orfolk}, ' ...
'journal = {Brit. Birds}, ' ...
'year = {1983}, ' ...
'volume = {76}, ' ...
'pages = {291-304}, ' ...
'author = {N. J. Westwood}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Burhinus_oedicnemus}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'HumeKirw2020'; type = 'Misc'; bib = [ ... 
'doi = {10.2173/bow.eutkne1.01}, ' ...
'author = {Hume, R. and G. M. Kirwan}, ' ... 
'year = {2020}, ' ...
'title = {Eurasian Thick-knee (\emph{Burhinus oedicnemus}), version 1.0. In Birds of the World (J. del Hoyo, A. Elliott, J. Sargatal, D. A. Christie, and E. de Juana, Editors). Cornell Lab of Ornithology, Ithaca, NY, USA}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];


